@@ -6,8 +6,9 @@ use Catmandu::Expander;
 use Catmandu::Breaker;
 use namespace::clean;
 
-our $VERSION = '0.03';
+our $VERSION = '0.10';
 
+has tags    => (is => 'ro' , default => sub { +{} });
 has breaker => (is => 'lazy');
 
 sub _build_breaker {
@@ -24,9 +25,11 @@ sub add {
 
     for my $tag (sort keys %$collapse) {
         my $value = $collapse->{$tag};
-        
+
         $tag =~ s{\.\d+}{[]}g;
 
+        $self->tags->{$tag} = 1;
+
         $io->print(
             $self->breaker->to_breaker(
                 $identifier ,
@@ -40,4 +43,4 @@ sub add {
 
 1;
 
-__END__
\ No newline at end of file
+__END__
