@@ -5,8 +5,9 @@ use Moo;
 use Catmandu::Breaker;
 use namespace::clean;
 
-our $VERSION = '0.03';
+our $VERSION = '0.10';
 
+has tags    => (is => 'ro' , default => sub { +{} });
 has breaker => (is => 'lazy');
 
 sub _build_breaker {
@@ -23,6 +24,8 @@ sub add {
     for my $field (@$record) {
         my ($tag,$ind1,$ind2,@data) = @$field;
 
+        $self->tags->{$tag} = 1;
+
         my $txt = '';
 
         for (my $i = 0 ; $i < @data ; $i += 2) {
@@ -50,4 +53,4 @@ sub add {
 
 1;
 
-__END__
\ No newline at end of file
+__END__
