@@ -6,8 +6,9 @@ use Catmandu::Breaker;
 use Carp;
 use namespace::clean;
 
-our $VERSION = '0.03';
+our $VERSION = '0.10';
 
+has tags    => (is => 'ro' , default => sub { +{} });
 has breaker => (is => 'lazy');
 
 sub _build_breaker {
@@ -22,6 +23,8 @@ sub add {
     $self->xpath_gen($data,[],sub {
         my ($tag,$value) = @_;
 
+        $self->tags->{$tag} = 1;
+        
         $io->print(
             $self->breaker->to_breaker(
                 $identifier ,
@@ -62,4 +65,4 @@ sub xpath_gen {
 
 1;
 
-__END__
\ No newline at end of file
+__END__
